#!/bin/sh

if [ -n "$EH_PREFIX" ]; then
	export PREFIX="$EH_PREFIX"
fi

if [ -z "$PREFIX" ]; then
	echo "ERROR: set \$PREFIX before sourcing this script!"
	exit 1
fi

# set some basic OS stuff
SW_VERSION=`sw_vers -productVersion | cut -d. -f1-2`
case $SW_VERSION in
	10.[01])
		echo "unsupported OS version: $SW_VERSION"
		exit 1
		;;
	10.2)
		export MACOSX_DEPLOYMENT_TARGET=10.2
		FREETYPE_CONFIG=$PREFIX/bin/freetype-config
		;;
	10.3)
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config
		;;
	10.4)
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config

		GCCCMD="gcc"
		[ -n "$CC" ] && GCCCMD="$CC"

		if [ `$GCCCMD --version 2>&1 | grep -c ' 4.0.0 '` -gt 0 ]; then
			cat <<END
=== ERROR === ERROR === ERROR === ERROR === ERROR === ERROR ===

You are using GCC 4.0.0, which is known to compile KDE, but
produce bad code.  Please update to XCode 2.2 or higher.

=== ERROR === ERROR === ERROR === ERROR === ERROR === ERROR ===
END
			exit 1
		fi
		;;
	*)
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config
		;;
esac

LDFLAGS=""

if [ -n "$USE_UNSERMAKE" ] && [ "$USE_UNSERMAKE" -gt 0 ]; then
	UNSERMAKEFLAGS=`perl -e '$ENV{MAKEFLAGS} =~ s/^.*?-j(\d+).*?$/-j1 --compile-jobs=$1/; print $ENV{MAKEFLAGS}'`
	UNSERMAKEFLAGS="$UNSERMAKEFLAGS -p"
	MAKEFLAGS=""
fi

#for dir in freetype2 xft2 render1 fontconfig2 xrender1 flex; do
for dir in system-openssl freetype219 fontconfig2 flex doxygen1.3; do
	if [ -d "$PREFIX/lib/$dir" ]; then
		for incdir in "$PREFIX/lib/$dir/include/freetype2" "$PREFIX/lib/$dir/include"; do
			if [ -d "$incdir" ]; then
				export CPPFLAGS="$CPPFLAGS -I$incdir"
			fi
		done
		[ -d "$PREFIX/lib/$dir/lib" ]           && export LDFLAGS="-L$PREFIX/lib/$dir/lib $LDFLAGS"
		[ -d "$PREFIX/lib/$dir/bin" ]           && export PATH="$PREFIX/lib/$dir/bin:$PATH"
		[ -d "$PREFIX/lib/$dir/lib/pkgconfig" ] && export PKG_CONFIG_PATH="$PREFIX/lib/$dir/lib/pkgconfig:$PKG_CONFIG_PATH"
	fi
done

# -fast, minus the unsafe bits
if [ -d "libltdl" ]; then
	export ACLOCALFLAGS="$ACLOCALFLAGS -I libltdl"
fi
export CFLAGS="-Os -fPIC"
export CXXFLAGS="$CFLAGS"
export CPPFLAGS="$CPPFLAGS -fno-common -no-cpp-precomp -DMACOSX -DARTS_NO_ALARM -I$PREFIX/include -I/usr/X11R6/include"
export FREETYPE_CONFIG
export LIBS="$LIBS -L$PREFIX/lib -L/usr/X11R6/lib"
export SED="sed"
export CONFIGURE_PARAMS="--includedir=$PREFIX/include --libdir=$PREFIX/lib --prefix=$PREFIX --with-extra-libs=$PREFIX/lib --with-extra-includes=$PREFIX/include --enable-mt --with-pic --enable-rpath --enable-shared=yes --enable-static=no --mandir=$PREFIX/share/man --with-xinerama --with-pam --disable-final --with-ssl-dir=/usr --with-ssl --disable-dependency-tracking --enable-gcc-hidden-visibility"

# miscellaneous stuff that packages use
export lt_cv_sys_max_cmd_len=65536
export HOME=/tmp
export QTDOCDIR="$PREFIX/share/doc/qt3/html"
[ -x "$PREFIX/lib/flex/bin/flex" ] && export LEX="$PREFIX/lib/flex/bin/flex"

if [ -e "$PREFIX/lib/qt3/include" ]; then
	CONFIGURE_PARAMS="$CONFIGURE_PARAMS --with-qt-dir=$PREFIX/lib/qt3"
else
	CONFIGURE_PARAMS="$CONFIGURE_PARAMS --with-qt-dir=$PREFIX --with-qt-includes=$PREFIX/include/qt"
fi

PATH=`echo $PATH | perl -p -e 'for my $entry (split(/:/, $_)) { next if ($entry =~ m,^/usr/local,); push(@path, $entry) }; $_ = join(":", @path)'`
export PATH="$PATH:/usr/X11R6/bin"

export ALL_LIBRARIES="$LDFLAGS -L$PREFIX/lib -L/usr/X11R6/lib"

cat <<END
the following environment is being used:

  ACLOCALFLAGS:             $ACLOCALFLAGS
  CFLAGS:                   $CFLAGS
  CPPFLAGS:                 $CPPFLAGS
  CXXFLAGS:                 $CXXFLAGS
  FREETYPE_CONFIG:          $FREETYPE_CONFIG
  LDFLAGS:                  $LDFLAGS
  LIBS:                     $LIBS
  MACOSX_DEPLOYMENT_TARGET: $MACOSX_DEPLOYMENT_TARGET
  PATH:                     $PATH
  PKG_CONFIG_PATH:          $PKG_CONFIG_PATH
  CONFIGURE_PARAMS:         $CONFIGURE_PARAMS
  UNSERMAKEFLAGS:           $UNSERMAKEFLAGS
  MAKEFLAGS:                $MAKEFLAGS

END
